# scad2gltf

scad2gltf is a python library for converting openscad code into colour gltf files using OpenSCAD and [pygltflib](https://gitlab.com/dodgyville/pygltflib).

scad2gltf was inspired by [colorscad](https://github.com/jschobben/colorscad) but does not use code from it.
